Geodyn
Author: Yannick Martin - Geodynamo - ISTerre
Description: Animated visualisation of flow on earth core surface

#### <<<

#### >>>

Home page

#### Visualizations

Earth's core surface
Magnetic field and flow
Cross-sections
Time series along Θ or Φ
Spherical harmonics
Coeficients times series
Lowes-Mauersberger spectra
For all displayed quantities
Observatories data
Geomagnetic or Virtual

#### Download

Exporting model data
As lists of coefficients
Options
Loading ...
Scientific contact
nicolas.gillet@univ-grenoble-alpes.fr
Technical contact
franck.thollard@univ-grenoble-alpes.fr
loic.huder@univ-grenoble-alpes.fr